@@ -13,9 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -152,6 +152,7 @@ int ephp_parse(char *phpstr,char ***values)
 {
    char *s,*php_instr,*buf;
    int i;
+   int size;
    php_instr=(char *)xmalloc(sizeof(char *));
    php_instr[0]='\0';
    buf=phpstr;
@@ -159,7 +160,8 @@ int ephp_parse(char *phpstr,char ***values)
       s=strstr(buf,";");
       if(s!=NULL) {
 	 php_instr=(char *)xrealloc(php_instr,(s-buf)+1);
-	 memset(php_instr,'\0',sizeof(php_instr));
+	 size=sizeof(php_instr);
+	 memset(php_instr,'\0',size);
 	 php_instr[s-buf]='\0'; 
 	 strncpy(php_instr,buf,s-buf);
       }
@@ -190,31 +192,52 @@ int found=0;
 if((fp=fopen(filename,"r"))==NULL) return(-1);
 
 while (fgets(buffer,500,fp)) {
-s=strstr(buffer,"<?");
 
-if (!found) {
-   if (s==NULL) printf("%s",buffer);
-     else {
-          strncpy(buffer2,buffer,s-buffer);
-          buffer2[s-buffer]='\0';
-          printf("%s",buffer2);
-          found=1;
-          strcpy(buffer2,buffer);
-          strcpy(buffer,buffer2+(s-buffer)+2);
-     }
-}
-if (found) {
-   buffer2[0]='\0';
-   s=strstr(buffer,"?>");
-   if(s!=NULL) {
-     fseek(fp,0-((buffer+strlen(buffer))-s-2),SEEK_CUR);
-     *s='\0'; 
-     found=0;
-   }
-   if(ephp_parse(buffer,values)==-1) return(-1);  
-}
+	s=strstr(buffer,"<?");
+
+	if (!found) {
+
+   		if (s==NULL) printf("%s",buffer);
+
+     		else {
+
+          		strncpy(buffer2,buffer,s-buffer);
+          		buffer2[s-buffer]='\0';
+          		printf("%s",buffer2);
+          		found=1;
+          		strcpy(buffer2,buffer);
+          		strcpy(buffer,buffer2+(s-buffer)+2);
+
+     		}
+
+	}
+
+	if (found) {
+
+   		buffer2[0]='\0';
+   		s=strstr(buffer,"?>");
+
+   		if(s!=NULL) {
+
+     			fseek(fp,0-((buffer+strlen(buffer))-s-2),SEEK_CUR);
+     			*s='\0'; 
+     			found=0;
+
+   		}
+
+   		if(ephp_parse(buffer,values)==-1) {
+
+			fclose(fp);
+	 		return(-1);  
+
+   		}
+
+	}
     
 }
+
 fflush(stdout);
+fclose(fp);
 return(0);
+
 }
