@@ -13,9 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -336,15 +336,27 @@ if (uf) {
    char *mppath = _PATH_PWD;
 #endif
    
-   if(!( pid=fork() )) {
-      if (!name)
-         execl(_PATH_PWD_MKDB,"pwd_mkdb","-p","-d",mppath,TMPFILE,NULL);
-      else
-         execl(_PATH_PWD_MKDB,"pwd_mkdb","-p","-d",mppath,"-u",name,TMPFILE,NULL);
-   }
-   pid = waitpid(pid,&pstat,0);
+	if(!( pid=fork() )) {
+
+      		if (!name) {
+
+         		execl(_PATH_PWD_MKDB,"pwd_mkdb","-p","-d",mppath,TMPFILE,NULL);
+
+		}
+      		else {
+
+         		execl(_PATH_PWD_MKDB,"pwd_mkdb","-p","-d",mppath,"-u",name,TMPFILE,NULL);
+
+		}
+
+      		return(-14);
+   	}
+
+   	pid = waitpid(pid,&pstat,0);
+
+   	if ((pid==-1 || !WIFEXITED(pstat) || WEXITSTATUS(pstat) != 0)) return(-14);
+
 
-   if (!(pid=-1 || !WIFEXITED(pstat) || WEXITSTATUS(pstat) != 0)) return(-14);
 #endif
 }
 else { 
