@@ -92,6 +92,11 @@ struct pw_info * get_pw(char *name);
 int ckpw(struct pw_info *pw,char *pass);
 int chpw_nopam(struct pw_info *pw,char *pass,int mode);
 int chpw(struct pw_info *pw,char *pass);
+
+
+char * set_shadow_location ( char * shadow_file );
+char * set_passwd_location ( char * passwd_file );
+
 #ifdef _WITHPAM
 int ckpw_nopam(struct pw_info *pw,char *pass);
 struct pw_info * get_pw_nopam(char *name);
