@@ -1,7 +1,7 @@
 /*
  * write_log.c
  *
- * Copyright (C) 2001, 2007 Staf Wagemakers Belgie/Belgium
+ * Copyright (C) 2001, 2007, 2013 Staf Wagemakers Belgie/Belgium
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,9 +13,9 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
@@ -89,7 +89,7 @@ void write_log(int facility, int priority, char *fmt, ...)
   strncpy(syslog_msg,prefix,255);
   strncat(syslog_msg,clientmsg,255-strlen(syslog_msg));
   strncat(syslog_msg,buf,255-strlen(syslog_msg));
-  syslog(priority,syslog_msg);
+  syslog(priority,"%s",syslog_msg);
   closelog();
 }
   
